@@ -20,23 +20,21 @@ def get_ecses():
 def cli():
     ecses = get_ecses()
     while True:
-        try:
-            os.system('clear')
-            for i in range(len(ecses)):
-                print(''.join([str(i+1), ':', ecses[i].__str__()]))
-            while True:
-                try:
-                    index = int(input('请选择ECS序号:'))
-                    break
-                except IndexError:
-                    pass
-            cur_ecs=ecses[index-1]
-            sship = cur_ecs.ip
-            # sship = '127.0.0.1'
-            print('ecs',':',cur_ecs.__str__())
-            os.system('ssh ' + sship)
-        except SyntaxError as e:
-            pass
+        os.system('clear')
+        for i in range(len(ecses)):
+            print(''.join([str(i+1), ':', ecses[i].__str__()]))
+
+        indexstr=input('请选择ECS序号:')
+        if not indexstr.isdigit():
+            continue
+        if int(indexstr)>len(ecses):
+            continue
+
+        cur_ecs=ecses[int(indexstr)-1]
+        sship = cur_ecs.ip
+        # sship = '127.0.0.1'
+        print('ecs',':',cur_ecs.__str__())
+        os.system('ssh ' + sship)
 
 
 if __name__ == '__main__':
